<?php

class YResilience_API {

	private $website_id = null;
	private $api_key = null;
	private $api_url = 'api.yavli.com/v2';
	private $is_wp_vip = false;

	static $instance = false;

	public static function init() {
		if ( ! self::$instance ) {
			self::$instance = new YResilience_API;
		}
		return self::$instance;
	}

	function __construct() {
		$this->api_result = null;
		$this->api_status = null;

		$this->api_reachable = null;

		$this->api_error_code = null;
		$this->api_error_detail = null;
	}

	public function set_wp_vip() {
		$this->is_wp_vip = true;
	}

	private function get_api_url( $path, $use_ssl = true ) {
		if ( $use_ssl )
			return 'https://' . $this->api_url . $path;
		else
			return 'http://' . $this->api_url . $path;
	}

	private function get_auth_headers() {
		return array(
			'X-WebsiteID'     => YResilience_Options::get_option( 'website_id' ),
			'X-ApiKey'        => YResilience_Options::get_option( 'api_key' ),
			'X-PluginVersion' => YRESILIENCE_VERSION
		);
	}

	protected function api_request( $action, $custom_args = array() ) {
		$default_args = array(
			'timeout'     => 5,
			'redirection' => 5,
			'httpversion' => '1.1',
			'user-agent'  => 'WordPress/ ' . get_bloginfo( 'url' ),
			'blocking'    => true,
			'headers'     => $this->get_auth_headers(),
			'cookies'     => array(),
			'body'        => null,
			'compress'    => false,
			'decompress'  => true,
			'sslverify'   => true,
			'stream'      => false,
			'filename'    => null
		);
		$args = array_merge( $default_args, $custom_args );

		$url_ssl = $this->get_api_url( $action );
		$url = $this->get_api_url( $action, $use_ssl = false );

		if ( $this->is_wp_vip ) {
			$response = vip_safe_wp_remote_get( $url_ssl, $fallback_value='', $threshold = 3, $timeout = 2, $retry = 20, $args );
		} else {
			$response = wp_safe_remote_get( $url_ssl, $args );
			if ( !is_array( $response ) ) {
				$response = wp_safe_remote_get( $url, $args );
				if ( !is_array( $response ) ) {
					$response = wp_remote_get( $url_ssl, $args );
					if ( !is_array( $response ) ) {
						$response = wp_remote_get( $url, $args );
					}
				}
			}
		}

		$response_body = wp_remote_retrieve_body( $response );


		$result = json_decode( $response_body );
		if ( $result != null ) {
			$this->api_reachable = true;

			if ( property_exists( $result, 'error' ) ) {
				$this->api_status = $result->error->status;
				$this->api_error_code = $result->error->code;
				$this->api_error_detail = $result->error->detail;
			} else {
				$this->api_status = 200;
				$this->api_result = $result;
			}

		} else {
			$this->api_reachable = false;
		}
	}

	public function get_ad_server() {
		$this->api_request( '/get-ad-server' );
		if ($this->api_reachable == true && $this->api_status == 200) {
			return true;
		}
		return false;
	}

	public function get_full_error_msg() {
		$msg = 'API Reachable: ';
		$msg .= ( $this->api_reachable ? 'Yes' : 'No');
		$msg .= ", API Status: '" . $this->api_status . "', ";
		$msg .= "API Error Code: '" . $this->api_error_code . "', ";
		$msg .= "API Error Detail: '" . $this->api_error_detail . "'";
		return $msg;
	}
}
