<?php

class YResilience_Options {

	public static function get_option_names() {

		return array(
			'website_id',                   // (int)    The Website ID.
			'api_key',                      // (string) The Website's API Key.
			'enabled',                      // (bool)   Whether the whole plugin is enabled or not.
			'last_heartbeat',               // (int)    The timestamp of the last heartbeat that fired.
			'last_error_msg',               // (string) Last error message, if any.
			'last_update_method',           // (string) manual or cron.
			'last_update_at',               // (string) manual or cron.
			'init_js',                      // (string) ad_server object
		);
	}

	public static function is_valid( $name ) {
		if ( in_array( $name, self::get_option_names() ) ) {
			return true;
		}

		return false;
	}

	/**
	 * Returns the requested option.  Looks in yresilience_options.
	 *
	 * @param string $name Option name
	 * @param mixed $default (optional)
	 */
	public static function get_option( $name, $default = false ) {
		if ( self::is_valid( $name ) ) {
			return get_option( 'yresilience_' . $name, $default );
		}

		trigger_error( sprintf( 'Invalid Yavli Resilience option name: %s', $name ), E_USER_WARNING );

		return $default;
	}

	/**
	 * Updates the single given option.  Updates yresilience_options.
	 *
	 * @param string $name Option name
	 * @param mixed $value Option value
	 */
	public static function update_option( $name, $value ) {
		if ( self::is_valid( $name ) ) {
			return update_option( 'yresilience_' . $name, $value );
		}

		trigger_error( sprintf( 'Invalid Yavli Resilience option name: %s', $name ), E_USER_WARNING );

		return false;
	}

	/**
	 * Updates the multiple given options.  Updates yresilience_options.
	 *
	 * @param array $array array( option name => option value, ... )
	 */
	public static function update_options( $array ) {
		$result = true;
		$names = array_keys( $array );

		$unknown_names = array_diff( $names, self::get_option_names() );

		foreach ( $unknown_names as $unknown_name ) {
			trigger_error( sprintf( 'Invalid Resilience option name: %s', $unknown_name ), E_USER_WARNING );
			unset( $array[ $unknown_name ] );
			$result = false;
		}

		$names = array_diff( $names, $unknown_names );

		foreach ( $names as $name ) {
			$result = self::update_option( $name, $array[ $name ] ) && $result;
		}
		return $result;
	}

	/**
	 * Deletes the given option.  May be passed multiple option names as an array.
	 * Updates yresilience_options.
	 *
	 * @param string|array $names
	 */
	public static function delete_option( $names ) {
		$result = true;
		$names  = ( array ) $names;

		foreach ( $names as $name ) {
			if ( ! self::is_valid( $name ) ) {
				trigger_error( sprintf( 'Invalid Resilience option names: %s', print_r( $names, 1 ) ), E_USER_WARNING );

				$result = false;
			}
			$result = delete_option( 'yresilience_' . $name ) && $result;
		}
		return $result;
	}

}
