<?php

class YResilience {

	var $host = array(
		'is_wp_vip'  => false,
	);

	var $cache = array(
		'w3_total_cache'  => false,
		'super_cache'     => false,
		'fast_cache'      => false,
		'wp_rocket'       => false,
	);

	public function __construct() {
		$this->do_host_detection();
		$this->do_cache_detection();
	}

	public static function plugin_activation() {
		wp_clear_scheduled_hook( 'wp_yavli_cron' );
	}

	public static function plugin_deactivation() {
		wp_clear_scheduled_hook( 'wp_yavli_cron' );
	}

	public function refresh_ad_server( $update_method = 'manual' ) {

		$api = YResilience_API::init();
		if ( $this->host['is_wp_vip'] ) {
			$api->set_wp_vip();
		}
		$success = $api->get_ad_server();

		if ( !$success ) {
			YResilience_Options::update_option( 'last_error_msg', $api->get_full_error_msg() );
			return false;
		}
		YResilience_Options::update_option( 'last_error_msg', '' );

		// save the init javascript locally
		YResilience_Options::update_option( 'init_js', $api->api_result->data->init_js );

		YResilience_Options::update_option( 'last_update_at', time() );

		if ( !in_array( $update_method, array( 'manual', 'cron', 'push' ) ) ) {
			$update_method = 'manual';
		}

		YResilience_Options::update_option( 'last_update_method', $update_method );

		return true;
	}

	public function do_host_detection() {
		if ( function_exists( 'vip_safe_wp_remote_get' ) ) {
			$this->host['is_wp_vip'] = true;
		}
	}

	public function do_cache_detection() {
		if ( function_exists( 'w3tc_flush_all' ) ) {
			$this->cache['w3_total_cache'] = true;
		}
		if ( function_exists( 'wp_cache_clear_cache' ) ) {
			$this->cache['super_cache'] = true;
		}
		global $wpfc;
		if ($wpfc) {
			$this->cache['fast_cache'] = true;
		}
		if ( function_exists( 'rocket_clean_domain' ) ) {
			$this->cache['wp_rocket'] = true;
		}
	}

	public function cache_clear_w3_total_cache() {
		w3tc_flush_all();
	}
	public function cache_clear_super_cache() {
		wp_cache_clear_cache();
	}
	public function cache_clear_fast_cache() {
		global $wpfc;
		if ( $wpfc ) {
			$wpfc->deleteCache();
		}
	}
	public function cache_clear_wp_rocket_cache() {
		rocket_clean_domain();
	}
	// clear any cache we know about
	public function cache_clear_all() {
		// cache purging is not necessary on wordpress.com hosted sites
		if ( $this->host['is_wp_vip'] ) {
			return;
		}
		if ( $this->cache['w3_total_cache'] ) {
			$this->cache_clear_w3_total_cache();
		}
		if ( $this->cache['super_cache'] ) {
			$this->cache_clear_super_cache();
		}
		if ( $this->cache['fast_cache'] ) {
			$this->cache_clear_fast_cache();
		}
		if ( $this->cache['wp_rocket'] ) {
			$this->cache_clear_wp_rocket_cache();
		}
	}

}
